<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RMLSend - Macro Command Utility</source>
        <translation type="obsolete">RMLEnvio -  Utilitároo de Comandos Macro</translation>
    </message>
    <message>
        <source>RML</source>
        <translation>RML</translation>
    </message>
    <message>
        <source>RML (no echo)</source>
        <translation>RML (no echo)</translation>
    </message>
    <message>
        <source>Set Port</source>
        <translation>Escolher Porta</translation>
    </message>
    <message>
        <source>UDP Port:</source>
        <translation>Porta UDP:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <source>Response:</source>
        <translation>Resposta:</translation>
    </message>
    <message>
        <source>&amp;Send Command</source>
        <translation>&amp;Enviar Comando</translation>
    </message>
    <message>
        <source>RMLSend</source>
        <translation>RMLEnvio</translation>
    </message>
    <message>
        <source>Invalid Port Number!</source>
        <translation>Número de Porta Inválida!</translation>
    </message>
    <message>
        <source>Connection Failed!</source>
        <translation>Conexão Falhou!</translation>
    </message>
    <message>
        <source>no response</source>
        <translation>Sem Resposta</translation>
    </message>
    <message>
        <source>Macro Command Utility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
